@@ -15,14 +15,9 @@ import time
 
 from cryptography.fernet import Fernet
 
+from .common import red, blue
 DOCTR_WORKING_BRANCH = '__doctr_working_branch'
 
-def red(text):
-    return "\033[31m%s\033[0m" % text
-
-def blue(text):
-    return "\033[34m%s\033[0m" % text
-
 def decrypt_file(file, key):
     """
     Decrypts the file ``file``.
@@ -364,20 +359,32 @@ def find_sphinx_build_dir():
 
 def copy_to_tmp(source):
     """
-    Copies ``source`` to a temporary directory, and returns the copied location.
+    Copies ``source`` to a temporary directory, and returns the copied
+    location.
+
+    If source is a file, the copied location is also a file.
     """
     tmp_dir = tempfile.mkdtemp()
     # Use pathlib because os.path.basename is different depending on whether
     # the path ends in a /
     p = pathlib.Path(source)
-    new_dir = os.path.join(tmp_dir, p.name)
+    dirname = p.name or 'temp'
+    new_dir = os.path.join(tmp_dir, dirname)
     if os.path.isdir(source):
         shutil.copytree(source, new_dir)
     else:
         shutil.copy2(source, new_dir)
     return new_dir
 
-def sync_from_log(src, dst, log_file):
+def is_subdir(a, b):
+    """
+    Return true if a is a subdirectory of b
+    """
+    a, b = map(os.path.abspath, [a, b])
+
+    return os.path.commonpath([a, b]) == b
+
+def sync_from_log(src, dst, log_file, exclude=()):
     """
     Sync the files in ``src`` to ``dst``.
 
@@ -388,9 +395,14 @@ def sync_from_log(src, dst, log_file):
     ``src`` (even if it already existed in ``dst``), and ``removed`` is every
     file from ``log_file`` that was removed from ``dst`` because it wasn't in
     ``src``. ``added`` also includes the log file.
+
+    ``exclude`` may be a list of paths from ``src`` that should be ignored.
+    Such paths are neither added nor removed, even if they are in the logfile.
     """
     from os.path import join, exists, isdir
 
+    exclude = [os.path.normpath(i) for i in exclude]
+
     added, removed = [], []
 
     if not exists(log_file):
@@ -402,7 +414,9 @@ def sync_from_log(src, dst, log_file):
 
         for new_f in files:
             new_f = new_f.strip()
-            if exists(new_f):
+            if any(is_subdir(new_f, os.path.join(dst, i)) for i in exclude):
+                pass
+            elif exists(new_f):
                 os.remove(new_f)
                 removed.append(new_f)
             else:
@@ -418,6 +432,8 @@ def sync_from_log(src, dst, log_file):
 
     # sorted makes this easier to test
     for f in sorted(files):
+        if any(is_subdir(f, os.path.join(src, i)) for i in exclude):
+            continue
         new_f = join(dst, f[len(src):])
         if isdir(f):
             os.makedirs(new_f, exist_ok=True)
